Project description
TOPSIS
Author: Kinjal Goyal.

Type: Package.

Title: TOPSIS method for multiple-criteria decision making (MCDM).

Version: 1.1.0

Date: 2022-1-22

Maintainer: Kinjal Goyal kgoyal1_be20@thapar.edu.

Description: Evaluation of alternatives based on multiple criteria using TOPSIS method

What is TOPSIS?

Technique for Order Preference by Similarity to Ideal Solution.

TOPSIS chooses the alternative of shortest Euclidean distance from the ideal solution,

and greatest distance from the negative-ideal solution.


In Command Prompt

>> python topsis.py 102003532-data.csv “1,1,1,1,1” “+,-,+,-,+” 102003532-result.csv